# from utils import saybye
import argparse
import logging
import os.path
from typing import Dict, List, cast



# def main(args: List[str]) -> None:
#     parser = argparse.ArgumentParser(prog="twine upload")
#     # settings.Settings.register_argparse_arguments(parser)
#     parser.add_argument(
#         "dists",
#         nargs="+",
#         metavar="dist",
#         help="The distribution files to upload to the repository "
#              "(package index). Usually dist/* . May additionally contain "
#              "a .asc file to include an existing signature with the "
#              "file upload.",
#     )
#
#     parsed_args = parser.parse_args(args)
#
#     print("upload main ")
#     # upload_settings = settings.Settings.from_argparse(parsed_args)
#
#     # Call the upload function with the arguments from the command line
#     # return upload(upload_settings, parsed_args.dists)


def main():
    print('he111llo')
    # saybye()

def main2():
    print('hello222')
    # saybye()


#
# if __name__=='__main__':
#     main()